@@ -5,8 +5,7 @@
 #include "jamdummy.h"
 #include "phitsdummy.h"
 
-c #include "epLightWLS.f"  ! now moved to prog/UserMayChange
-c #include "epAutoEmin.f"  ! //
+#include "epLightWLS.f"
 c       ****************
         program stdepics
         implicit none
